@@ -425,8 +425,8 @@ call_helper_get_method_in_signature (GDBusConnection  *c,
   GVariant *result;
   GDBusNodeInfo *node_info;
   const gchar *xml_data;
-  const GDBusInterfaceInfo *interface_info;
-  const GDBusMethodInfo *method_info;
+  GDBusInterfaceInfo *interface_info;
+  GDBusMethodInfo *method_info;
   guint n;
 
   ret = NULL;
@@ -1398,6 +1398,7 @@ monitor_on_name_appeared (GDBusConnection *connection,
                                                           NULL,  /* any member */
                                                           opt_monitor_object_path,
                                                           NULL,  /* arg0 */
+                                                          G_DBUS_SIGNAL_FLAGS_NONE,
                                                           monitor_signal_cb,
                                                           NULL,  /* user_data */
                                                           NULL); /* user_data destroy notify */
