@@ -157,21 +157,20 @@ static gboolean
 key_exists (GSettings   *settings,
             const gchar *name)
 {
-  const gchar **keys;
+  gchar **keys;
   gint i;
   gboolean ret;
 
   ret = FALSE;
 
-  keys = g_settings_list_items (settings);
+  keys = g_settings_list_keys (settings);
   for (i = 0; keys[i]; i++)
-    if (!g_str_has_suffix (keys[i], "/") &&
-        g_strcmp0 (keys[i], name) == 0)
+    if (g_strcmp0 (keys[i], name) == 0)
       {
         ret = TRUE;
         break;
       }
-  g_free (keys);
+  g_strfreev (keys);
 
   return ret;
 }
@@ -180,17 +179,16 @@ static void
 list_keys (GSettings   *settings,
            const gchar *prefix)
 {
-  const gchar **keys;
+  gchar **keys;
   gint i;
 
-  keys = g_settings_list_items (settings);
+  keys = g_settings_list_keys (settings);
   for (i = 0; keys[i]; i++)
     {
-      if (!g_str_has_suffix (keys[i], "/") &&
-          (prefix == NULL || g_str_has_prefix (keys[i], prefix)))
+      if (prefix == NULL || g_str_has_prefix (keys[i], prefix))
         g_print ("%s \n", keys[i]);
     }
-  g_free (keys);
+  g_strfreev (keys);
 }
 
 static void
