@@ -27,7 +27,6 @@
 #include "giomodule-priv.h"
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gvfs
@@ -250,6 +249,3 @@ g_vfs_get_local (void)
 
   return G_VFS (vfs);
 }
-
-#define __G_VFS_C__
-#include "gioaliasdef.c"
