@@ -620,12 +620,21 @@ parse_args (gint    *argc_p,
   *argc_p = e;
 }
 
+static gboolean
+do_nothing (gpointer data)
+{
+  return TRUE;
+}
+
 int
 main (int    argc,
       char **argv)
 {
   guint ui;
 
+  /* See #578295 */
+  g_timeout_add_seconds (5, do_nothing, NULL);
+
   /* some unices need SA_RESTART for SIGCHLD to return -EAGAIN for io.
    * we must fiddle with sigaction() *before* glib is used, otherwise
    * we could revoke signal hanmdler setups from glib initialization code.
@@ -672,7 +681,7 @@ main (int    argc,
 
   close (log_fd);
 
-  return 0;
+  return testcase_fail_count == 0 ? 0 : 1;
 }
 
 static void
