@@ -21,10 +21,10 @@
  * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GLib Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GLib at ftp://ftp.gtk.org/pub/gtk/. 
+ * GLib at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-/* 
+/*
  * MT safe
  */
 
@@ -37,9 +37,9 @@
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 
-#ifndef G_OS_WIN32
 #include <sys/time.h>
 #include <time.h>
+#ifndef G_OS_WIN32
 #include <errno.h>
 #endif /* G_OS_WIN32 */
 
@@ -47,7 +47,11 @@
 #include <windows.h>
 #endif /* G_OS_WIN32 */
 
-#include "glib.h"
+#include "gtimer.h"
+
+#include "gmem.h"
+#include "gstrfuncs.h"
+#include "gtestutils.h"
 #include "gthread.h"
 
 /**
@@ -437,7 +441,7 @@ g_time_val_from_iso8601 (const gchar *iso_date,
       return FALSE;
     }
 
-  *iso_date++;
+  iso_date++;
 
   /* If there is a 'T' then there has to be a time */
   if (!g_ascii_isdigit (*iso_date))
