@@ -33,7 +33,6 @@
 #include "gparam.h"
 #include "gboxed.h"
 #include "genums.h"
-#include "gobjectalias.h"
 
 
 /* --- value functions --- */
@@ -1130,15 +1129,7 @@ g_value_get_pointer (const GValue *value)
   return value->data[0].v_pointer;
 }
 
-GType
-g_gtype_get_type (void)
-{
-  static const GTypeInfo type_info = { 0, };
-  static GType type;
-  if (!type)
-    type = g_type_register_static (G_TYPE_POINTER, g_intern_static_string ("GType"), &type_info, 0);
-  return type;
-}
+G_DEFINE_POINTER_TYPE (GType, g_gtype)
 
 /**
  * g_value_set_gtype:
@@ -1179,7 +1170,7 @@ g_value_get_gtype (const GValue *value)
 
 /**
  * g_value_set_variant:
- * @value: a valid #GValue of %G_TYPE_VARIANT
+ * @value: a valid #GValue of type %G_TYPE_VARIANT
  * @variant: a #GVariant, or %NULL
  *
  * Set the contents of a variant #GValue to @variant.
@@ -1206,9 +1197,48 @@ g_value_set_variant (GValue   *value,
     g_variant_unref (old_variant);
 }
 
+/**
+ * g_value_take_variant:
+ * @value: a valid #GValue of type %G_TYPE_VARIANT
+ * @variant: a #GVariant, or %NULL
+ *
+ * Set the contents of a variant #GValue to @variant, and takes over
+ * the ownership of the caller's reference to @variant;
+ * the caller doesn't have to unref it any more (i.e. the reference
+ * count of the variant is not increased).
+ * 
+ * It is a programmer error to pass a floating variant to this function.
+ * In particular this means that callbacks in closures, and signal handlers
+ * for signals of return type %G_TYPE_VARIANT, must never return floating
+ * variants.
+ *
+ * If you want the #GValue to hold its own reference to @variant, use
+ * g_value_set_variant() instead.
+ *
+ * This is an internal function introduced mainly for C marshallers.
+ *
+ * Since: 2.26
+ */
+void
+g_value_take_variant (GValue   *value,
+                      GVariant *variant)
+{
+  GVariant *old_variant;
+
+  g_return_if_fail (G_VALUE_HOLDS_VARIANT (value));
+  g_return_if_fail (variant == NULL || !g_variant_is_floating (variant));
+
+  old_variant = value->data[0].v_pointer;
+
+  value->data[0].v_pointer = variant;
+
+  if (old_variant)
+    g_variant_unref (old_variant);
+}
+
 /**
  * g_value_get_variant:
- * @value: a valid #GValue of %G_TYPE_VARIANT
+ * @value: a valid #GValue of type %G_TYPE_VARIANT
  *
  * Get the contents of a variant #GValue.
  *
@@ -1226,7 +1256,7 @@ g_value_get_variant (const GValue *value)
 
 /**
  * g_value_dup_variant:
- * @value: a valid #GValue of %G_TYPE_VARIANT
+ * @value: a valid #GValue of type %G_TYPE_VARIANT
  *
  * Get the contents of a variant #GValue, increasing its refcount.
  *
@@ -1309,6 +1339,25 @@ g_strdup_value_contents (const GValue *value)
 	contents = g_strdup_printf ("((%s*) %p)", G_OBJECT_TYPE_NAME (p), p);
       else if (G_VALUE_HOLDS_PARAM (value))
 	contents = g_strdup_printf ("((%s*) %p)", G_PARAM_SPEC_TYPE_NAME (p), p);
+      else if (G_VALUE_HOLDS (value, G_TYPE_STRV))
+        {
+          GStrv strv = g_value_get_boxed (value);
+          GString *tmp = g_string_new ("[");
+
+          while (*strv != NULL)
+            {
+              gchar *escaped = g_strescape (*strv, NULL);
+
+              g_string_append_printf (tmp, "\"%s\"", escaped);
+              g_free (escaped);
+
+              if (*++strv != NULL)
+                g_string_append (tmp, ", ");
+            }
+
+          g_string_append (tmp, "]");
+          contents = g_string_free (tmp, FALSE);
+        }
       else if (G_VALUE_HOLDS_BOXED (value))
 	contents = g_strdup_printf ("((%s*) %p)", g_type_name (G_VALUE_TYPE (value)), p);
       else if (G_VALUE_HOLDS_POINTER (value))
@@ -1355,6 +1404,3 @@ g_pointer_type_register_static (const gchar *name)
 
   return type;
 }
-
-#define __G_VALUETYPES_C__
-#include "gobjectaliasdef.c"
